@@ -1,8 +1,9 @@
 """Delete time series data from InfluxDB."""
 
-import datetime
+from datetime import datetime
 
 from influxdb_client import DeleteService, DeletePredicateRequest
+from influxdb_client.client.util.date_utils import get_date_helper
 
 
 class DeleteApi(object):
@@ -24,5 +25,11 @@ class DeleteApi(object):
         :param org: organization id or name
         :return:
         """
+        date_helper = get_date_helper()
+        if isinstance(start, datetime):
+            start = date_helper.to_utc(start)
+        if isinstance(stop, datetime):
+            stop = date_helper.to_utc(stop)
+
         predicate_request = DeletePredicateRequest(start=start, stop=stop, predicate=predicate)
         return self._service.post_delete(delete_predicate_request=predicate_request, bucket=bucket, org=org)
