@@ -3,10 +3,12 @@
 from __future__ import absolute_import
 
 import configparser
+import logging
 import os
 import base64
+import warnings
 
-from influxdb_client import Configuration, ApiClient, HealthCheck, HealthService, Ready, ReadyService
+from influxdb_client import Configuration, ApiClient, HealthCheck, HealthService, Ready, ReadyService, PingService
 from influxdb_client.client.authorizations_api import AuthorizationsApi
 from influxdb_client.client.bucket_api import BucketsApi
 from influxdb_client.client.delete_api import DeleteApi
@@ -18,6 +20,9 @@ from influxdb_client.client.users_api import UsersApi
 from influxdb_client.client.write_api import WriteApi, WriteOptions, PointSettings
 
 
+logger = logging.getLogger(__name__)
+
+
 class InfluxDBClient(object):
     """InfluxDBClient is client for InfluxDB v2."""
 
@@ -247,15 +252,88 @@ class InfluxDBClient(object):
                    connection_pool_maxsize=_to_int(connection_pool_maxsize), auth_basic=_to_bool(auth_basic),
                    profilers=profilers)
 
-    def write_api(self, write_options=WriteOptions(), point_settings=PointSettings()) -> WriteApi:
+    def write_api(self, write_options=WriteOptions(), point_settings=PointSettings(), **kwargs) -> WriteApi:
         """
         Create a Write API instance.
 
-        :param point_settings:
-        :param write_options: write api configuration
+        Example:
+            .. code-block:: python
+
+                from influxdb_client import InfluxDBClient
+                from influxdb_client.client.write_api import SYNCHRONOUS
+
+
+                # Initialize SYNCHRONOUS instance of WriteApi
+                with InfluxDBClient(url="http://localhost:8086", token="my-token", org="my-org") as client:
+                    write_api = client.write_api(write_options=SYNCHRONOUS)
+
+        If you would like to use a **background batching**, you have to configure client like this:
+
+        .. code-block:: python
+
+            from influxdb_client import InfluxDBClient
+
+            # Initialize background batching instance of WriteApi
+            with InfluxDBClient(url="http://localhost:8086", token="my-token", org="my-org") as client:
+                with client.write_api() as write_api:
+                    pass
+
+        There is also possibility to use callbacks to notify about state of background batches:
+
+        .. code-block:: python
+
+            from influxdb_client import InfluxDBClient
+            from influxdb_client.client.exceptions import InfluxDBError
+
+
+            class BatchingCallback(object):
+
+                def success(self, conf: (str, str, str), data: str):
+                    print(f"Written batch: {conf}, data: {data}")
+
+                def error(self, conf: (str, str, str), data: str, exception: InfluxDBError):
+                    print(f"Cannot write batch: {conf}, data: {data} due: {exception}")
+
+                def retry(self, conf: (str, str, str), data: str, exception: InfluxDBError):
+                    print(f"Retryable error occurs for batch: {conf}, data: {data} retry: {exception}")
+
+
+            with InfluxDBClient(url="http://localhost:8086", token="my-token", org="my-org") as client:
+                callback = BatchingCallback()
+                with client.write_api(success_callback=callback.success,
+                                      error_callback=callback.error,
+                                      retry_callback=callback.retry) as write_api:
+                    pass
+
+        :param write_options: Write API configuration
+        :param point_settings: settings to store default tags
+        :key success_callback: The callable ``callback`` to run after successfully writen a batch.
+
+                               The callable must accept two arguments:
+                                    - `Tuple`: ``(bucket, organization, precision)``
+                                    - `str`: written data
+
+                               **[batching mode]**
+
+        :key error_callback: The callable ``callback`` to run after unsuccessfully writen a batch.
+
+                             The callable must accept three arguments:
+                                - `Tuple`: ``(bucket, organization, precision)``
+                                - `str`: written data
+                                - `Exception`: an occurred error
+
+                             **[batching mode]**
+        :key retry_callback: The callable ``callback`` to run after retryable error occurred.
+
+                             The callable must accept three arguments:
+                                - `Tuple`: ``(bucket, organization, precision)``
+                                - `str`: written data
+                                - `Exception`: an retryable error
+
+                             **[batching mode]**
         :return: write api instance
         """
-        return WriteApi(influxdb_client=self, write_options=write_options, point_settings=point_settings)
+        return WriteApi(influxdb_client=self, write_options=write_options, point_settings=point_settings, **kwargs)
 
     def query_api(self, query_options: QueryOptions = QueryOptions()) -> QueryApi:
         """
@@ -330,6 +408,7 @@ class InfluxDBClient(object):
 
         :return: HealthCheck
         """
+        warnings.warn("This method is deprecated. Call 'ping()' instead.", DeprecationWarning)
         health_service = HealthService(self.api_client)
 
         try:
@@ -338,6 +417,36 @@ class InfluxDBClient(object):
         except Exception as e:
             return HealthCheck(name="influxdb", message=str(e), status="fail")
 
+    def ping(self) -> bool:
+        """
+        Return the the status of InfluxDB instance.
+
+        :return: The status of InfluxDB.
+        """
+        ping_service = PingService(self.api_client)
+
+        try:
+            ping_service.get_ping()
+            return True
+        except Exception as ex:
+            logger.debug("Unexpected error during /ping: %s", ex)
+            return False
+
+    def version(self) -> str:
+        """
+        Return the version of the connected InfluxDB Server.
+
+        :return: The version of InfluxDB.
+        """
+        ping_service = PingService(self.api_client)
+
+        response = ping_service.get_ping_with_http_info(_return_http_data_only=False)
+        if response is not None and len(response) >= 3:
+            if 'X-Influxdb-Version' in response[2]:
+                return response[2]['X-Influxdb-Version']
+
+        return "unknown"
+
     def ready(self) -> Ready:
         """
         Get The readiness of the InfluxDB 2.0.
