@@ -7,10 +7,10 @@ Flux is InfluxData’s functional data scripting language designed for querying,
 import codecs
 import csv
 from datetime import datetime, timedelta
-from typing import List, Generator, Any
+from typing import List, Generator, Any, Union, Iterable, Callable
 
 from influxdb_client import Dialect, IntegerLiteral, BooleanLiteral, FloatLiteral, DateTimeLiteral, StringLiteral, \
-    VariableAssignment, Identifier, OptionStatement, File, DurationLiteral, Duration, UnaryExpression, \
+    VariableAssignment, Identifier, OptionStatement, File, DurationLiteral, Duration, UnaryExpression, Expression, \
     ImportDeclaration, MemberAssignment, MemberExpression, ArrayExpression
 from influxdb_client import Query, QueryService
 from influxdb_client.client.flux_csv_parser import FluxCsvParser, FluxSerializationMode
@@ -22,13 +22,15 @@ from influxdb_client.client.util.helpers import get_org_query_param
 class QueryOptions(object):
     """Query options."""
 
-    def __init__(self, profilers: List[str] = None) -> None:
+    def __init__(self, profilers: List[str] = None, profiler_callback: Callable = None) -> None:
         """
         Initialize query options.
 
         :param profilers: list of enabled flux profilers
+        :param profiler_callback: callback function return profilers (FluxRecord)
         """
         self.profilers = profilers
+        self.profiler_callback = profiler_callback
 
 
 class QueryApi(object):
@@ -101,7 +103,7 @@ class QueryApi(object):
                                               async_req=False, _preload_content=False, _return_http_data_only=False)
 
         _parser = FluxCsvParser(response=response, serialization_mode=FluxSerializationMode.tables,
-                                profilers=self._profilers())
+                                query_options=self._get_query_options())
 
         list(_parser.generator())
 
@@ -123,7 +125,7 @@ class QueryApi(object):
         response = self._query_api.post_query(org=org, query=self._create_query(query, self.default_dialect, params),
                                               async_req=False, _preload_content=False, _return_http_data_only=False)
         _parser = FluxCsvParser(response=response, serialization_mode=FluxSerializationMode.stream,
-                                profilers=self._profilers())
+                                query_options=self._get_query_options())
 
         return _parser.generator()
 
@@ -131,7 +133,8 @@ class QueryApi(object):
         """
         Execute synchronous Flux query and return Pandas DataFrame.
 
-        Note that if a query returns more then one table than the client generates a DataFrame for each of them.
+        Note that if a query returns tables with differing schemas than the client generates
+        a DataFrame for each of them.
 
         :param query: the Flux query
         :param str, Organization org: specifies the organization for executing the query;
@@ -157,7 +160,8 @@ class QueryApi(object):
         """
         Execute synchronous Flux query and return stream of Pandas DataFrame as a Generator['pd.DataFrame'].
 
-        Note that if a query returns more then one table than the client generates a DataFrame for each of them.
+        Note that if a query returns tables with differing schemas than the client generates
+        a DataFrame for each of them.
 
         :param query: the Flux query
         :param str, Organization org: specifies the organization for executing the query;
@@ -174,17 +178,18 @@ class QueryApi(object):
 
         _parser = FluxCsvParser(response=response, serialization_mode=FluxSerializationMode.dataFrame,
                                 data_frame_index=data_frame_index,
-                                profilers=self._profilers())
+                                query_options=self._get_query_options())
         return _parser.generator()
 
-    def _profilers(self):
+    def _get_query_options(self):
         if self._query_options and self._query_options.profilers:
-            return self._query_options.profilers
-        else:
-            return self._influxdb_client.profilers
+            return self._query_options
+        elif self._influxdb_client.profilers:
+            return QueryOptions(profilers=self._influxdb_client.profilers)
 
     def _create_query(self, query, dialect=default_dialect, params: dict = None):
-        profilers = self._profilers()
+        query_options = self._get_query_options()
+        profilers = query_options.profilers if query_options is not None else None
         q = Query(query=query, dialect=dialect, extern=QueryApi._build_flux_ast(params, profilers))
 
         if profilers:
@@ -203,35 +208,43 @@ class QueryApi(object):
 
         statements = []
         for key, value in params.items():
-            if value is None:
+            expression = QueryApi._parm_to_extern_ast(value)
+            if expression is None:
                 continue
 
-            if isinstance(value, bool):
-                literal = BooleanLiteral("BooleanLiteral", value)
-            elif isinstance(value, int):
-                literal = IntegerLiteral("IntegerLiteral", str(value))
-            elif isinstance(value, float):
-                literal = FloatLiteral("FloatLiteral", value)
-            elif isinstance(value, datetime):
-                value = get_date_helper().to_utc(value)
-                literal = DateTimeLiteral("DateTimeLiteral", value.strftime('%Y-%m-%dT%H:%M:%S.%fZ'))
-            elif isinstance(value, timedelta):
-                _micro_delta = int(value / timedelta(microseconds=1))
-                if _micro_delta < 0:
-                    literal = UnaryExpression("UnaryExpression", argument=DurationLiteral("DurationLiteral", [
-                        Duration(magnitude=-_micro_delta, unit="us")]), operator="-")
-                else:
-                    literal = DurationLiteral("DurationLiteral", [Duration(magnitude=_micro_delta, unit="us")])
-            elif isinstance(value, str):
-                literal = StringLiteral("StringLiteral", str(value))
-            else:
-                literal = value
-
             statements.append(OptionStatement("OptionStatement",
                                               VariableAssignment("VariableAssignment", Identifier("Identifier", key),
-                                                                 literal)))
+                                                                 expression)))
         return statements
 
+    @staticmethod
+    def _parm_to_extern_ast(value) -> Union[Expression, None]:
+        if value is None:
+            return None
+        if isinstance(value, bool):
+            return BooleanLiteral("BooleanLiteral", value)
+        elif isinstance(value, int):
+            return IntegerLiteral("IntegerLiteral", str(value))
+        elif isinstance(value, float):
+            return FloatLiteral("FloatLiteral", value)
+        elif isinstance(value, datetime):
+            value = get_date_helper().to_utc(value)
+            return DateTimeLiteral("DateTimeLiteral", value.strftime('%Y-%m-%dT%H:%M:%S.%fZ'))
+        elif isinstance(value, timedelta):
+            _micro_delta = int(value / timedelta(microseconds=1))
+            if _micro_delta < 0:
+                return UnaryExpression("UnaryExpression", argument=DurationLiteral("DurationLiteral", [
+                    Duration(magnitude=-_micro_delta, unit="us")]), operator="-")
+            else:
+                return DurationLiteral("DurationLiteral", [Duration(magnitude=_micro_delta, unit="us")])
+        elif isinstance(value, str):
+            return StringLiteral("StringLiteral", str(value))
+        elif isinstance(value, Iterable):
+            return ArrayExpression("ArrayExpression",
+                                   elements=list(map(lambda it: QueryApi._parm_to_extern_ast(it), value)))
+        else:
+            return value
+
     @staticmethod
     def _build_flux_ast(params: dict = None, profilers: List[str] = None):
 
